import{p as e,b as t}from"./p-f350f2d0.js";export{s as setNonce}from"./p-f350f2d0.js";import{g as r}from"./p-e1255160.js";(()=>{const s=import.meta.url,t={};return""!==s&&(t.resourcesUrl=new URL(".",s).href),e(t)})().then((async s=>(await r(),t([["p-da2cc61f",[[0,"django-hstore-widget",{json:[1],field_name:[1],delete_svg_src:[1],add_svg_src:[1],edit_svg_src:[1],output_render_type:[32],_json:[32],_json_string:[32]}]]]],s))));